@@ -1,6 +1,6 @@
 package P9Y::ProcessTable::Table;
 
-our $VERSION = '1.05_01'; # VERSION
+our $VERSION = '1.05_02'; # VERSION
 
 #############################################################################
 # Modules
@@ -27,9 +27,9 @@ die $@ if $@ and $@ !~ /^Can't locate /;
 
 unless ($has_os_role) {
    # let's hope they have /proc
-   if ( -d '/proc' ) { $role = 'ProcFS'; }
+   if ( -d '/proc' and @{[ glob('/proc/*') ]} ) { $role = 'ProcFS'; }
    # ...or that Proc::ProcessTable can handle it
-   else              { $role = 'PPT';    }
+   else                                         { $role = 'PPT'; }
 }
 
 # This here first, so that it gets overloaded
